@@ -16,7 +16,7 @@ use LWP::UserAgent;
 use METS::Files;
 use Perl6::Slurp qw(slurp);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -35,7 +35,7 @@ sub new {
 
 	if (defined $self->{'lwp_user_agent'}) {
 		if (! $self->{'lwp_user_agent'}->isa('LWP::UserAgent')) {
-			err "Parameter 'lwp_user_agent' must be a LWP::UserAgent object.";
+			err "Parameter 'lwp_user_agent' must be a LWP::UserAgent instance.";
 		}
 	} else {
 		$self->{'lwp_user_agent'} = LWP::UserAgent->new;
@@ -82,7 +82,7 @@ sub run {
 
 	$self->{'_kramerius_obj'} = $self->{'_kramerius'}->get($kramerius_id);
 	if (! defined $self->{'_kramerius_obj'}) {
-		err "Library with ID '$self->{'_kramerius_id'}' is unknown.";
+		err "Library with ID '$kramerius_id' is unknown.";
 	}
 	barf('ROOT', <<"END");
 $kramerius_id
@@ -301,7 +301,7 @@ Returns 1 for error, 0 for success.
  new():
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
-         Parameter 'lwp_user_agent' must be a LWP::UserAgent object.
+         Parameter 'lwp_user_agent' must be a LWP::UserAgent instance.
 
  run():
          Bad version of Kramerius.
@@ -375,6 +375,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
